# LanguageSettings

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**display_language** | **str** | The language to display Gmail in, formatted as an RFC 3066 Language Tag (for example &#x60;en-GB&#x60;, &#x60;fr&#x60; or &#x60;ja&#x60; for British English, French, or Japanese respectively). The set of languages supported by Gmail evolves over time, so please refer to the \&quot;Language\&quot; dropdown in the Gmail settings for all available options, as described in the language settings help article. A table of sample values is also provided in the Managing Language Settings guide Not all Gmail clients can display the same set of languages. In the case that a user&#x27;s display language is not available for use on a particular client, said client automatically chooses to display in the closest supported variant (or a reasonable default). | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

